@@ -1,7 +1,3 @@
-import pytest
-
-
-@pytest.mark.asyncio
 async def test_ping_no_param(app_client):
     """
     Test ping endpoint with a mocked client.
